Task: Cornell Movie
====================
Description: Fictional conversations extracted from raw movie scripts. Danescu-Niculescu-Mizil & Lee, '11. 

Link: https://arxiv.org/abs/1106.3077

Tags: #CornellMovie, #All, #ChitChat

